@@ -25,10 +25,24 @@ roundDown(int numToRound, int multiple)
         return numToRound;
     
     int remainder = numToRound % multiple;
-    if (remainder == 0)
+    if (remainder == 0 || remainder == numToRound)
         return numToRound;
     
     return numToRound - remainder;
 }
 
+inline
+int 
+roundUp(int numToRound, int multiple)
+{
+	if (multiple == 0)
+		return numToRound;
+	
+	int remainder = numToRound % multiple;
+	if (remainder == 0 || multiple == numToRound)
+		return numToRound;
+	
+	return numToRound + multiple - remainder;
+}
+
 #endif
