@@ -428,37 +428,40 @@ cpp_gpuMatrix_eucl(
     viennacl::context ctx(viennacl::ocl::get_context(ptrA->getContext()));
     
     viennacl::matrix<T> vcl_A = ptrA->device_data();
-    viennacl::matrix<T> vcl_D = viennacl::zero_matrix<T>(vcl_A.size1(), vcl_A.size2(), ctx = ctx);
+    viennacl::matrix<T> vcl_D = viennacl::zero_matrix<T>(vcl_A.size1(), vcl_A.size1(), ctx = ctx);
     
-    // other temp objects
-    viennacl::matrix<T> square_A = viennacl::zero_matrix<T>(vcl_A.size1(), vcl_A.size2(), ctx = ctx);
-    
-    const int K = vcl_A.size1();
-      
     // temp objects
     // viennacl::vector_base<T> row_ones = static_cast<viennacl::vector_base<T> >(viennacl::scalar_vector<T>(K, 1, ctx = ctx));
     // viennacl::vector_base<T> vcl_sqrt = static_cast<viennacl::vector_base<T> >(viennacl::zero_vector<T>(K, ctx = ctx));
-    viennacl::vector_base<T> row_ones = viennacl::vector_base<T>(K, ctx = ctx);
-    viennacl::vector_base<T> vcl_sqrt = viennacl::vector_base<T>(K, ctx = ctx);
-    viennacl::linalg::vector_assign(row_ones, (T)(1));
-    viennacl::linalg::vector_assign(vcl_sqrt, (T)(0));
+    // viennacl::vector_base<T> vcl_sqrt = viennacl::vector_base<T>(K, ctx = ctx);
+    
+    viennacl::vector_base<T> vcl_sqrt;
     
     // this will definitely need to be updated with the next ViennaCL release
     // currently doesn't support the single scalar operation with
     // element_pow below
-    viennacl::matrix<T> twos = viennacl::scalar_matrix<T>(K, K, 2, ctx = ctx);
+    {
+        viennacl::matrix<T> twos = viennacl::scalar_matrix<T>(vcl_A.size1(), vcl_A.size2(), 2, ctx = ctx);
+        
+        viennacl::matrix<T> square_A = viennacl::linalg::element_pow(vcl_A, twos);
+        
+        vcl_sqrt = viennacl::linalg::row_sum(square_A);
+    }
     
-    square_A = viennacl::linalg::element_pow(vcl_A, twos);
-    vcl_sqrt = viennacl::linalg::row_sum(square_A);
-    
-    vcl_D = viennacl::linalg::outer_prod(vcl_sqrt, row_ones);
+    {
+        // viennacl::vector_base<T> row_ones = static_cast<viennacl::vector_base<T> >(viennacl::scalar_vector<T>(vcl_A.size1(), 1, ctx));
+        viennacl::vector_base<T> row_ones = viennacl::vector_base<T>(vcl_A.size1(), ctx = ctx);
+        viennacl::linalg::vector_assign(row_ones, (T)(1));
+        
+        vcl_D = viennacl::linalg::outer_prod(vcl_sqrt, row_ones);
+    }
     
     vcl_D += trans(vcl_D);
     
     vcl_D -= 2 * (viennacl::linalg::prod(vcl_A, trans(vcl_A)));
     
     if(!squareDist){
-        vcl_D = viennacl::linalg::element_sqrt(vcl_D);    
+        vcl_D = viennacl::linalg::element_sqrt(vcl_D);   
     }
     
     for(unsigned int i=0; i < vcl_D.size1(); i++){
@@ -557,52 +560,33 @@ cpp_vclMatrix_eucl(
     viennacl::matrix_range<viennacl::matrix<T> > vcl_A = ptrA->data();
     viennacl::matrix_range<viennacl::matrix<T> > vcl_D = ptrD->data();
     
-//    std::cout << "pulled data" << std::endl;
-//    std::cout << vcl_A.size1() << std::endl;
-    
-//    viennacl::vector_base<T> vcl_sqrt = viennacl::zero_vector<T>(vcl_A.size1());
     viennacl::vector_base<T> vcl_sqrt;
     
-//    std::cout << "row of zeros" << std::endl;
-    
     // this will definitely need to be updated with the next ViennaCL release
     // currently doesn't support the single scalar operation with
     // element_pow below
     {
         viennacl::matrix<T> twos = viennacl::scalar_matrix<T>(vcl_A.size1(), vcl_A.size2(), 2, ctx);
-    
-//        std::cout << "create 'twos' matrix" << std::endl;
         
         viennacl::matrix<T> square_A = viennacl::linalg::element_pow(vcl_A, twos);
         vcl_sqrt = viennacl::linalg::row_sum(square_A);
     }
     
     
-//    std::cout << "powers and rowsum completed" << std::endl;
-    
     {
         // viennacl::vector_base<T> row_ones = static_cast<viennacl::vector_base<T> >(viennacl::scalar_vector<T>(vcl_A.size1(), 1, ctx));
         viennacl::vector_base<T> row_ones = viennacl::vector_base<T>(vcl_A.size1(), ctx = ctx);
         viennacl::linalg::vector_assign(row_ones, (T)(1));
         
-//        std::cout << "row of ones" << std::endl;
-        
         vcl_D = viennacl::linalg::outer_prod(vcl_sqrt, row_ones);
     }
     
-//    std::cout << "outer product completed" << std::endl;
-    
-//    std::cout << vcl_D << std::endl;
-    
     vcl_D += trans(vcl_D);
     
-//    std::cout << vcl_D << std::endl;
-    
 //    viennacl::matrix<T> temp = 2 * (viennacl::linalg::prod(vcl_A, trans(vcl_A)));
     
-//    std::cout << temp << std::endl;
     vcl_D -= 2 * (viennacl::linalg::prod(vcl_A, trans(vcl_A)));
-//    vcl_D -= temp;
+    
     if(!squareDist){
         vcl_D = viennacl::linalg::element_sqrt(vcl_D);    
     }
@@ -610,7 +594,6 @@ cpp_vclMatrix_eucl(
     for(unsigned int i=0; i < vcl_D.size1(); i++){
         vcl_D(i,i) = 0;
     }
-//    viennacl::diag(vcl_D) = viennacl::zero_vector<T>(vcl_A.size1());
         
 }
 
