@@ -1,6 +1,8 @@
 library(gpuR)
 context("CPU deepcopy")
 
+current_context <- set_device_context("cpu")
+
 # set seed
 set.seed(123)
 
@@ -21,6 +23,7 @@ test_that("CPU Check Integer gpuVector deepcopy", {
     # deepcopy
     gpuB <- deepcopy(gpuA)
     
+    expect_equal(gpuA, gpuB)
     expect_is(gpuB, "igpuVector")
     expect_is(gpuB, class(gpuA))
     expect_equal(gpuA[], gpuB[],
@@ -40,6 +43,7 @@ test_that("CPU Check Single Precision gpuVector deepcopy", {
     # deepcopy
     gpuB <- deepcopy(gpuA)
     
+    expect_equal(gpuA, gpuB)
     expect_is(gpuB, class(gpuA))
     expect_equal(gpuA[], gpuB[], tolerance=1e-07, 
                  info="float deepcopy gpuVector elements not equivalent")  
@@ -58,6 +62,7 @@ test_that("CPU Check Double Precision gpuVector deepcopy", {
     # deepcopy
     gpuB <- deepcopy(gpuA)
     
+    expect_equal(gpuA, gpuB)
     expect_is(gpuB, class(gpuA))
     expect_equal(gpuA[], gpuB[], tolerance=.Machine$double.eps ^ 0.5, 
                  info="fgpuVector deepcopy elements not equivalent")  
@@ -76,6 +81,7 @@ test_that("CPU Check Integer gpuMatrix deepcopy", {
     # deepcopy
     gpuB <- deepcopy(gpuA)
     
+    expect_equal(gpuA, gpuB)
     expect_is(gpuB, "igpuMatrix")
     expect_is(gpuB, class(gpuA))
     expect_equal(gpuA[], gpuB[],
@@ -95,6 +101,7 @@ test_that("CPU Check Single Precision gpuMatrix deepcopy", {
     # deepcopy
     gpuB <- deepcopy(gpuA)
     
+    expect_equal(gpuA, gpuB)
     expect_is(gpuB, class(gpuA))
     expect_equal(gpuA[], gpuB[], tolerance=1e-07, 
                  info="float matrix elements not equivalent")  
@@ -113,6 +120,7 @@ test_that("CPU Check Double Precision gpuMatrix deepcopy", {
     # deepcopy
     gpuB <- deepcopy(gpuA)
     
+    expect_equal(gpuA, gpuB)
     expect_is(gpuB, class(gpuA))
     expect_equal(gpuA[], gpuB[], tolerance=.Machine$double.eps ^ 0.5, 
                  info="float matrix elements not equivalent")  
@@ -131,6 +139,7 @@ test_that("CPU Check Integer vclVector deepcopy", {
     # deepcopy
     vclB <- deepcopy(vclA)
     
+    expect_equal(vclA, vclB)
     expect_is(vclB, "ivclVector")
     expect_is(vclB, class(vclA))
     expect_equal(vclA[], vclB[],
@@ -150,6 +159,7 @@ test_that("CPU Check Single Precision vclVector deepcopy", {
     # deepcopy
     vclB <- deepcopy(vclA)
     
+    expect_equal(vclA, vclB)
     expect_is(vclB, class(vclA))
     expect_equal(vclA[], vclB[], tolerance=1e-07, 
                  info="float deepcopy vclVector elements not equivalent")  
@@ -168,6 +178,7 @@ test_that("CPU Check Double Precision vclVector deepcopy", {
     # deepcopy
     vclB <- deepcopy(vclA)
     
+    expect_equal(vclA, vclB)
     expect_is(vclB, class(vclA))
     expect_equal(vclA[], vclB[], tolerance=.Machine$double.eps ^ 0.5, 
                  info="fvclVector deepcopy elements not equivalent")  
@@ -186,6 +197,7 @@ test_that("CPU Check Integer vclMatrix deepcopy", {
     # deepcopy
     vclB <- deepcopy(vclA)
     
+    expect_equal(vclA, vclB)
     expect_is(vclB, "ivclMatrix")
     expect_is(vclB, class(vclA))
     expect_equal(vclA[], vclB[],
@@ -205,6 +217,7 @@ test_that("CPU Check Single Precision vclMatrix deepcopy", {
     # deepcopy
     vclB <- deepcopy(vclA)
     
+    expect_equal(vclA, vclB)
     expect_is(vclB, class(vclA))
     expect_equal(vclA[], vclB[], tolerance=1e-07, 
                  info="float matrix elements not equivalent")  
@@ -223,6 +236,7 @@ test_that("CPU Check Double Precision vclMatrix deepcopy", {
     # deepcopy
     vclB <- deepcopy(vclA)
     
+    expect_equal(vclA, vclB)
     expect_is(vclB, class(vclA))
     expect_equal(vclA[], vclB[], tolerance=.Machine$double.eps ^ 0.5, 
                  info="float matrix elements not equivalent")  
@@ -231,3 +245,5 @@ test_that("CPU Check Double Precision vclMatrix deepcopy", {
     expect_false(isTRUE(all.equal(vclA[], vclB[], tolerance = .Machine$double.eps ^ 0.5)),
                  info = "double deepcopy not distinct from source")
 })
+
+setContext(current_context)
