@@ -31,6 +31,19 @@ CMS <- colMeans(A[2:4, 2:4])
 
 S <- sum(A)
 
+test_that("vclMatrix Integer Precision Sum",
+{
+  has_gpu_skip()
+  
+  fgpuX <- vclMatrix(Aint, type="integer")
+  
+  gpuC <- sum(fgpuX)
+  
+  expect_is(gpuC, "integer")
+  expect_equivalent(gpuC[], sum(Ai), 
+                    info="integer sum not equivalent")  
+})
+
 test_that("vclMatrix Single Precision Sum",
 {
     has_gpu_skip()
@@ -333,6 +346,33 @@ test_that("vclMatrix Integer Precision rbind", {
 })
 
 # 'block' object tests
+test_that("vclMatrix Single Precision Block Sum",
+{
+    has_gpu_skip()
+    
+    fgpuX <- vclMatrix(A, type="float")
+    fgpuXS <- block(fgpuX, 2L,4L,2L,4L)
+    
+    gpuC <- sum(fgpuXS)
+    
+    expect_is(gpuC, "numeric")
+    expect_equal(gpuC[], sum(A[2:4, 2:4]), tolerance=1e-06, 
+                 info="float sum not equivalent")  
+})
+
+test_that("vclMatrix Double Precision Block Sum", 
+{
+    has_gpu_skip()
+    
+    dgpuX <- vclMatrix(A, type="double")
+    dgpuXS <- block(dgpuX, 2L,4L,2L,4L)
+    
+    gpuC <- sum(dgpuXS)
+    
+    expect_is(gpuC, "numeric")
+    expect_equal(gpuC[], sum(A[2:4,2:4]), tolerance=.Machine$double.eps ^ 0.5, 
+                 info="double colSums not equivalent")  
+})
 
 test_that("vclMatrix Single Precision Block Column Sums",
 {
